<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pl">
<context>
    <name>IsometricGridOff</name>
    <message>
        <location filename="../IsometricGridOff.js" line="+35"/>
        <source>Isometric Grid &amp;Off</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>&amp;Wyłączenie siatki izometrycznej</translation>
    </message>
</context>
</TS>
